[ARM] pxa: move declaration of 'pxa_last_gpio' into <mach/gpio.h>

Signed-off-by: Eric Miao <eric.miao@marvell.com>
diff --git a/arch/arm/mach-pxa/generic.h b/arch/arm/mach-pxa/generic.h
index bc12c94..3465268 100644
--- a/arch/arm/mach-pxa/generic.h
+++ b/arch/arm/mach-pxa/generic.h
@@ -20,7 +20,6 @@
 extern void __init pxa_map_io(void);
 
 extern unsigned int get_clk_frequency_khz(int info);
-extern int pxa_last_gpio;
 
 #define SET_BANK(__nr,__start,__size) \
 	mi->bank[__nr].start = (__start), \
diff --git a/arch/arm/mach-pxa/gpio.c b/arch/arm/mach-pxa/gpio.c
index 9a33eb0..4193559 100644
--- a/arch/arm/mach-pxa/gpio.c
+++ b/arch/arm/mach-pxa/gpio.c
@@ -20,6 +20,8 @@
 
 #include <mach/gpio.h>
 
+int pxa_last_gpio;
+
 #define GPIO0_BASE	(GPIO_REGS_VIRT + 0x0000)
 #define GPIO1_BASE	(GPIO_REGS_VIRT + 0x0004)
 #define GPIO2_BASE	(GPIO_REGS_VIRT + 0x0008)
@@ -38,8 +40,6 @@
 	void __iomem     *regbase;
 };
 
-int pxa_last_gpio;
-
 static int pxa_gpio_direction_input(struct gpio_chip *chip, unsigned offset)
 {
 	unsigned long        flags;
diff --git a/arch/arm/mach-pxa/include/mach/gpio.h b/arch/arm/mach-pxa/include/mach/gpio.h
index be4900e..4049b23 100644
--- a/arch/arm/mach-pxa/include/mach/gpio.h
+++ b/arch/arm/mach-pxa/include/mach/gpio.h
@@ -100,8 +100,11 @@
 
 
 /* NOTE: some PXAs have fewer on-chip GPIOs (like PXA255, with 85).
  * Those cases currently cause holes in the GPIO number space.
  */
+extern int pxa_last_gpio;
+
 #define NR_BUILTIN_GPIO 128
 
 static inline int gpio_get_value(unsigned gpio)
@@ -100,8 +100,11 @@
 
 /* NOTE: some PXAs have fewer on-chip GPIOs (like PXA255, with 85).
- * Those cases currently cause holes in the GPIO number space.
+ * Those cases currently cause holes in the GPIO number space, the
+ * actual number of the last GPIO is recorded by 'pxa_last_gpio'.
  */